/***************************************************************************
 *   Copyright (C) 2004-2008 by Giovanni Venturi                           *
 *   giovanni@ksniffer.org                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Steet, Fifth Floor, Boston, MA  02110-1301, USA.          *
 ***************************************************************************/

#ifndef KSNIFFERVIEWITEM_H
#define KSNIFFERVIEWITEM_H

class QListView;
class QListViewItem;
class PacketManager;
class PortNumberNameList;

class KSnifferViewItem : public QListViewItem
{
  public:
    KSnifferViewItem( QListView *parent, PacketManager *pm, PortNumberNameList *pnnl, bool showProtocolName );
    KSnifferViewItem( QListView *parent, QListViewItem *after, PacketManager *pm, PortNumberNameList *pnnl, bool showProtocolName );

    virtual int compare( QListViewItem * i, int col, bool ascending ) const;

  private:
    void init();

    PacketManager *m_packetData;
    PortNumberNameList *m_portNumberNameList;
    bool m_showProtocolName;
};

#endif
